@@ -1,8 +1,10 @@
 
-
 from .recon_acquisitions import recon_acquisitions
 from .recon_buffers import recon_buffers
+from .pass_through import pass_through
+
 __all__ = [
     recon_acquisitions,
-    recon_buffers
+    recon_buffers,
+    pass_through
 ]
